==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/product_controller.rb <==
# -*- coding: utf-8 -*-
class ProductController < ApplicationController
  class_desc :display_name => "商品管理"

  include EcRider::CloudFront

  def index
    session[:tmp_product_sku] = nil
    @condition = prepare_session_condition do |condition|
      condition || Product::SearchCondition.new(params[:condition])
    end
    unless @condition.valid?
      flash[:error] = @condition.errors.zip
      return
    end
    if msgs = flash[:destroy_error_messages]
      @product = Product.new
      msgs.each{|msg| @product.errors.add_to_base(msg)}
    end
    per_page = (@condition.disp_count || 20).to_i
    @products = Product.paginate(
      @condition.to_find_options_for_products_index(
        :page => params[:page], :per_page => per_page,
        :include => [:product_displays, :skus, :images])
    )
    
    if request.xml_http_request?
      render(:partial => "/product/search_result", :layout => false, :locals => {:invoked => 'csv'})
    end
  end

  # 詳細
  def show
    # 商品SKU確認画面表示に用いる一時情報を削除
    session[:tmp_product_sku] = nil
    
    @product = Product.find(params[:id], :include => :product_displays)

    ActiveRecord::Base.logger.debug("flash[:sku_error_messages]: #{flash[:sku_error_messages].inspect}")
    if msgs = flash[:sku_error_messages]
      msgs.each{|msg| @product.errors.add_to_base(msg)}
    end
    @product_display = @product.product_displays.find(:first, 
      :conditions => ["product_displays.locale = ?", params[:locale] || 'ja'])

    # 商品画像
    @images = ProductImage.find(:all, :conditions => ["product_id = ?", @product.id], :order => 'display_order')
    
    session[:product_form] = nil
  end

  # 編集
  def edit
    product_id = params[:id]
    @images = Product.image_list

    # 商品カテゴリ
    @product_categories = ProductCategory.find(:all, :conditions => ["parent_id IS NULL"], :order => :display_order)
    # 商品画像
    @product_images = ProductImage.find(:all, :conditions => ["parent_id IS NULL AND product_id = ?", product_id.to_i], :order => "display_order")

    if flash[:product]
      # 入力エラーの場合
      @product = flash[:product]
      @product_display = flash[:product_display]
      @invalid_product_displays = flash[:invalid_product_displays]
    elsif params[:product]
      # 戻るボタンで戻った場合
      @product = Product.find(product_id)
      @product.attributes = params[:product]
      @product_display = session[:product_form][:product_displays][params[:locale]]
    else
      # 新しく編集画面を開いた場合
      @product = Product.find(product_id)
      @product_display = @product.display_for(params[:locale] || 'ja', true)
      session[:product_form] = {:product_displays => {@product_display.locale => @product_display}}
    end

    # 商品画像に入力エラーがある場合
    @product_image = flash[:product_image] if flash[:product_image]
  end

  # 商品編集確認
  def confirm_update
    product_id = params[:id].to_i
    @product = Product.find(product_id)
    @product.attributes = params[:product]

    # 商品画像
    @images = ProductImage.find(:all, :conditions => ["product_id = ?", product_id], :order => 'display_order')
    
    # セッション内のproduct_displayを更新する
    target_product_display = session[:product_form][:product_displays][params[:product_display]['locale']]
    target_product_display.attributes = params[:product_display]
    session[:product_form][:product_displays][params[:product_display]['locale']] = target_product_display
    @product_display = target_product_display

    product_valid = @product.valid?

    # 登録した全言語分のproduct_displayのバリデーションチェック
    product_display_valid_flg = true
    invalid_product_displays = {}
    session[:product_form][:product_displays].each do |locale, product_display|
      unless product_display.valid?
        product_display_valid_flg = false
        invalid_product_displays[locale] = product_display
      end
    end

    if !product_valid || !product_display_valid_flg
      flash[:product] = @product
      flash[:product_display] = @product_display
      flash[:invalid_product_displays] = invalid_product_displays
      redirect_to(:action => :edit, :id => params[:id], :page => params[:page])
    end
  end

  def update
    product = Product.find(params[:id])
    product.attributes= params[:product]

    Product.transaction do
      product.save!
      # 商品画像とサムネイルをCloudFrontへアップロードする
      cloud_front_upload(product)

      session[:product_form][:product_displays].each do |locale, product_display|
        product_display.save!
      end
      flash[:notice] = "#{product.order_product_name_1}を更新しました。"
    end
    session[:product_form] = nil
    redirect_to :action => :show, :id => params[:id], :locale => params[:locale], :page => params[:page]
  end

  # 新規登録
  def new
    @images = Product.image_list
    # 商品カテゴリ
    @product_categories = ProductCategory.find(:all, :conditions => ["parent_id IS NULL"], :order => :display_order)

    @mobile_images = []
    if flash[:product]
      @product = flash[:product]
    elsif params[:product]
      @product = Product.new(params[:product])
    else
      @product = Product.new(:origin => 'JP')
    end
  end

  # 商品登録確認
  def confirm_create
    @product = Product.new(params[:product])

    product_valid = @product.valid?

    if !product_valid #|| !shipping_cost_valid_flg
      flash[:product] = @product
      redirect_to :action => :new
    end
  end

  def create
    Product.transaction do
      @product = Product.new(params[:product])
      @product.save!

      # 商品画像とサムネイルをCloudFrontへアップロードする
      cloud_front_upload(@product)

      flash[:notice] = "#{@product.order_product_name_1}を登録しました。"
    end
    redirect_to :action => :edit, :id => @product.id

  rescue Exception => e
    puts e
    puts e.backtrace.join("\n    ")
    raise
  end

  def destroy
    @product = Product.find(params[:id])
    @product.destroy
    # TODO 商品画像とサムネイルをCloudFrontから削除する
    
    flash[:destroy_error_messages] = @product.errors.full_messages
    redirect_to :action => :index, :page => params[:page]
  end

  private
  def cloud_front_upload(product)
    targets = product.image_sources
    timestamp = Time.now.strftime(ENV['ECR_TIMESTAMP'] || ::EcRider::CloudFront::CLOUD_FRONT_VERSION_FORMAT)
    s3 = Object.new
    s3.extend(::EcRider::CloudFront)
    s3.create_and_upload_to_s3(targets, :timestamp => timestamp)
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/product_controller.rb <==
# -*- coding: utf-8 -*-
class ProductController < ApplicationController
  class_desc :display_name => "商品管理"

  include EcRider::CloudFront

  def index
    session[:tmp_product_sku] = nil
    @condition = prepare_session_condition do |condition|
      condition || Product::SearchCondition.new(params[:condition])
    end
    unless @condition.valid?
      flash[:error] = @condition.errors.zip
      return
    end
    if msgs = flash[:destroy_error_messages]
      @product = Product.new
      msgs.each{|msg| @product.errors.add_to_base(msg)}
    end
    per_page = (@condition.disp_count || 20).to_i
    @products = Product.paginate(
      @condition.to_find_options_for_products_index(
        :page => params[:page], :per_page => per_page,
        :include => [:product_displays, :skus, :images])
    )
    
    if request.xml_http_request?
      render(:partial => "/product/search_result", :layout => false, :locals => {:invoked => 'csv'})
    end
  end

  # 詳細
  def show
    # 商品SKU確認画面表示に用いる一時情報を削除
    session[:tmp_product_sku] = nil
    
    @product = Product.find(params[:id], :include => :product_displays)

    ActiveRecord::Base.logger.debug("flash[:sku_error_messages]: #{flash[:sku_error_messages].inspect}")
    if msgs = flash[:sku_error_messages]
      msgs.each{|msg| @product.errors.add_to_base(msg)}
    end
    @product_display = @product.product_displays.find(:first, 
      :conditions => ["product_displays.locale = ?", params[:locale] || 'ja'])

    # 商品画像
    @images = ProductImage.find(:all, :conditions => ["product_id = ?", @product.id], :order => 'display_order')
    
    session[:product_form] = nil
  end

  # 編集
  def edit
    product_id = params[:id]
    @images = Product.image_list

    # 商品カテゴリ
    @product_categories = ProductCategory.find(:all, :conditions => ["parent_id IS NULL"], :order => :display_order)
    # 商品画像
    @product_images = ProductImage.find(:all, :conditions => ["parent_id IS NULL AND product_id = ?", product_id.to_i], :order => "display_order")

    if flash[:product]
      # 入力エラーの場合
      @product = flash[:product]
      @product_display = flash[:product_display]
      @invalid_product_displays = flash[:invalid_product_displays]
    elsif params[:product]
      # 戻るボタンで戻った場合
      @product = Product.find(product_id)
      @product.set_attributes_and_detail_url(params[:product])
      @product_display = session[:product_form][:product_displays][params[:locale]]
    else
      # 新しく編集画面を開いた場合
      @product = Product.find(product_id)
      @product_display = @product.display_for(params[:locale] || 'ja', true)
      session[:product_form] = {:product_displays => {@product_display.locale => @product_display}}
    end

    # 商品画像に入力エラーがある場合
    @product_image = flash[:product_image] if flash[:product_image]
  end

  # 商品編集確認
  def confirm_update
    product_id = params[:id].to_i
    @product = Product.find(product_id)
    @product.set_attributes_and_detail_url(params[:product])

    # 商品画像
    @images = ProductImage.find(:all, :conditions => ["product_id = ?", product_id], :order => 'display_order')
    
    # セッション内のproduct_displayを更新する
    target_product_display = session[:product_form][:product_displays][params[:product_display]['locale']]
    target_product_display.attributes = params[:product_display]
    session[:product_form][:product_displays][params[:product_display]['locale']] = target_product_display
    @product_display = target_product_display

    product_valid = @product.valid?

    # 登録した全言語分のproduct_displayのバリデーションチェック
    product_display_valid_flg = true
    invalid_product_displays = {}
    session[:product_form][:product_displays].each do |locale, product_display|
      unless product_display.valid?
        product_display_valid_flg = false
        invalid_product_displays[locale] = product_display
      end
    end

    if !product_valid || !product_display_valid_flg
      flash[:product] = @product
      flash[:product_display] = @product_display
      flash[:invalid_product_displays] = invalid_product_displays
      redirect_to(:action => :edit, :id => params[:id], :page => params[:page])
    end
  end

  def update
    product = Product.find(params[:id])
    product.set_attributes_and_detail_url(params[:product])

    Product.transaction do
      product.save!
      # 商品画像とサムネイルをCloudFrontへアップロードする
      cloud_front_upload(product)

      session[:product_form][:product_displays].each do |locale, product_display|
        product_display.save!
      end
      flash[:notice] = "#{product.order_product_name_1}を更新しました。"
    end
    session[:product_form] = nil
    redirect_to :action => :show, :id => params[:id], :locale => params[:locale], :page => params[:page]
  end

  # 新規登録
  def new
    @images = Product.image_list
    # 商品カテゴリ
    @product_categories = ProductCategory.find(:all, :conditions => ["parent_id IS NULL"], :order => :display_order)

    @mobile_images = []
    if flash[:product]
      @product = flash[:product]
    elsif params[:product]
      @product = Product.new()
      @product.set_attributes_and_detail_url(params[:product])
    else
      @product = Product.new(:origin => 'JP')
    end
  end

  # 商品登録確認
  def confirm_create
    @product = Product.new()
    @product.set_attributes_and_detail_url(params[:product])
    product_valid = @product.valid?

    if !product_valid #|| !shipping_cost_valid_flg
      flash[:product] = @product
      redirect_to :action => :new
    end
  end

  def create
    Product.transaction do
      @product = Product.new()
      @product.set_attributes_and_detail_url(params[:product])
      @product.save!

      # 商品画像とサムネイルをCloudFrontへアップロードする
      cloud_front_upload(@product)

      flash[:notice] = "#{@product.order_product_name_1}を登録しました。"
    end
    redirect_to :action => :edit, :id => @product.id

  rescue Exception => e
    puts e
    puts e.backtrace.join("\n    ")
    raise
  end

  def destroy
    @product = Product.find(params[:id])
    @product.destroy
    # TODO 商品画像とサムネイルをCloudFrontから削除する
    
    flash[:destroy_error_messages] = @product.errors.full_messages
    redirect_to :action => :index, :page => params[:page]
  end

  private
  def cloud_front_upload(product)
    targets = product.image_sources
    timestamp = Time.now.strftime(ENV['ECR_TIMESTAMP'] || ::EcRider::CloudFront::CLOUD_FRONT_VERSION_FORMAT)
    s3 = Object.new
    s3.extend(::EcRider::CloudFront)
    s3.create_and_upload_to_s3(targets, :timestamp => timestamp)
  end
end
